==> custom_pages-v1.12.9.zip: custom_pages/messages/hr/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Dodaj</strong> {templateName} stavku',
    '<strong>Custom</strong> Pages' => '<strong>Prilagođene</strong> stranice',
    '<strong>Edit</strong> snippet' => '<strong>Uredi</strong> isječak',
    'Add' => 'Dodaj',
    'Add a file icon before the title' => 'Dodajte ikonu datoteke prije naslova',
    'Adds plain HTML content to your site.' => 'Dodaje običan HTML sadržaj na vaše web mjesto.',
    'Advanced' => 'Napredno',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Omogućuje dodavanje stranica (označavanje, iframe ili veze) na prostornu navigaciju',
    'Allows you to add content in MarkDown syntax.' => 'Omogućuje dodavanje sadržaja u sintaksi MarkDown.',
    'Alternate text' => 'Alternativni tekst',
    'Always' => 'Uvijek',
    'Always make a backup of your view files outside of your production environment!' => 'Uvijek napravite sigurnosnu kopiju prikazanih datoteka izvan vašeg proizvodnog okruženja!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Prazan dopušteni odabir predloška omogućit će sve predloške spremnika za ovaj spremnik.',
    'Back' => 'Natrag',
    'Back to dashboard' => 'Povratak na upravljačku ploču',
    'Back to overview' => 'Natrag na pregled',
    'Back to space' => 'Povratak u prostor',
    'Category' => 'Kategorija',
    'Configuration' => 'Konfiguracija',
    'Content' => 'Sadržaj',
    'Create' => 'Kreiraj',
    'Css Class' => 'Css Class',
    'Custom' => 'Ostalo',
    'Custom Pages' => 'Prilagođene stranice',
    'Custom pages' => 'Prilagođene stranice',
    'Dashboard' => 'Upravljačka ploča',
    'Default' => 'Zadano',
    'Default Content' => 'Zadani sadržaj',
    'Delete' => 'Obriši.',
    'Edit' => 'Uredi',
    'Edit Page' => 'Uredi stranicu',
    'Empty' => 'Prazna',
    'File' => 'Datoteka',
    'General' => 'Općenito',
    'Html' => 'Html',
    'ID' => 'ID',
    'Iframe' => 'Iframe',
    'Insert' => 'Umetnuti',
    'Invalid type selection' => 'Nevažeći odabir vrste',
    'Link' => 'Poveznica',
    'MarkDown' => 'Smanjenje',
    'Navigation' => 'Navigacija',
    'On this page you can configure general settings of your custom pages.' => 'Na ovoj stranici možete konfigurirati opće postavke svojih prilagođenih stranica.',
    'Overview' => 'Pregled',
    'PHP' => 'PHP',
    'Page' => 'Stranica',
    'Pages' => 'Stranice',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Odaberite jednu od sljedećih vrsta sadržaja. Vrsta sadržaja definira kako je vaš sadržaj ugrađen na vašu web lokaciju.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Imajte na umu da su stranice temeljene na php-u osjetljive na sigurnosne probleme, posebno kada se rukuje korisničkim unosom. Za više informacija pogledajte <a href="{url}">Najbolji primjeri iz Yii-jeve sigurnosti</a>.',
    'Public' => 'Javno',
    'Reset' => 'Reset',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Odaberite ovu postavku samo za vidljive čvorove teksta. Poništite ovu postavku u slučaju da se ovaj element koristi, na primjer, kao vrijednost HTML atributa.',
    'Settings' => 'Postavke',
    'Show additional file information (size)' => 'Prikaži dodatne podatke o datoteci (veličina)',
    'Snippet' => 'Isječak',
    'Snippets' => 'Isječci',
    'Sort Order' => 'Redoslijed',
    'Source' => 'Izvor (Source)',
    'Space' => 'Prostor',
    'Space Members only' => 'Samo članovi prostora',
    'Space Navigation' => 'Navigacija prostora',
    'Spaces' => 'Prostori',
    'Stream' => 'Stream',
    'Style' => 'Stil',
    'Submit' => 'Potvrdi',
    'Template' => 'Predložak',
    'Templates' => 'Predlošci',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Predlošci vam omogućuju definiranje kombiniranih fragmenata stranice s ugrađenim funkcijama uređivanja.',
    'This container does not allow any further items!' => 'Ovaj spremnik ne dopušta daljnje predmete!',
    'Title' => 'Naziv',
    'Top Navigation' => 'Top navigacija',
    'Topics' => 'Teme',
    'Type' => 'Vrsta',
    'Upload image' => 'Dodaj sliku',
    'User Account Menu (Settings)' => 'Izbornik korisničkog računa (Postavke)',
    'Visibility' => 'Vidljivost',
    'Will embed the result of a given url as an iframe element.' => 'Hoće li ugrađivati rezultat određenog URL-a kao element iframe-a.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Hoće li preusmjeriti zahtjeve na zadani (relativni ili apsolutni) url.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Sa stranicama temeljenim na PHP-u možete stvoriti prilagođene stranice pomoću pregleda datoteka u vašem datotečnom sustavu. Molimo provjerite konfiguraciju modula za više informacija.',
    'Without adding to navigation (Direct link)' => 'Bez dodavanja u navigaciju (izravna veza)',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Authors' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Icon' => '',
    'Import' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template Layout' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/hr/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Dodaj</strong> {templateName} stavku',
    '<strong>Custom</strong> Pages' => '<strong>Prilagođene</strong> stranice',
    '<strong>Edit</strong> snippet' => '<strong>Uredi</strong> isječak',
    'Add' => 'Dodaj',
    'Add a file icon before the title' => 'Dodajte ikonu datoteke prije naslova',
    'Adds plain HTML content to your site.' => 'Dodaje običan HTML sadržaj na vaše web mjesto.',
    'Advanced' => 'Napredno',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Omogućuje dodavanje stranica (označavanje, iframe ili veze) na prostornu navigaciju',
    'Allows you to add content in MarkDown syntax.' => 'Omogućuje dodavanje sadržaja u sintaksi MarkDown.',
    'Alternate text' => 'Alternativni tekst',
    'Always' => 'Uvijek',
    'Always make a backup of your view files outside of your production environment!' => 'Uvijek napravite sigurnosnu kopiju prikazanih datoteka izvan vašeg proizvodnog okruženja!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Prazan dopušteni odabir predloška omogućit će sve predloške spremnika za ovaj spremnik.',
    'Back' => 'Natrag',
    'Back to dashboard' => 'Povratak na upravljačku ploču',
    'Back to overview' => 'Natrag na pregled',
    'Back to space' => 'Povratak u prostor',
    'Category' => 'Kategorija',
    'Configuration' => 'Konfiguracija',
    'Content' => 'Sadržaj',
    'Create' => 'Kreiraj',
    'Css Class' => 'Css Class',
    'Custom' => 'Ostalo',
    'Custom Pages' => 'Prilagođene stranice',
    'Custom pages' => 'Prilagođene stranice',
    'Dashboard' => 'Upravljačka ploča',
    'Default' => 'Zadano',
    'Default Content' => 'Zadani sadržaj',
    'Delete' => 'Obriši.',
    'Edit' => 'Uredi',
    'Edit Page' => 'Uredi stranicu',
    'Empty' => 'Prazna',
    'File' => 'Datoteka',
    'General' => 'Općenito',
    'Html' => 'Html',
    'ID' => 'ID',
    'Iframe' => 'Iframe',
    'Insert' => 'Umetnuti',
    'Invalid type selection' => 'Nevažeći odabir vrste',
    'Link' => 'Poveznica',
    'MarkDown' => 'Smanjenje',
    'Navigation' => 'Navigacija',
    'On this page you can configure general settings of your custom pages.' => 'Na ovoj stranici možete konfigurirati opće postavke svojih prilagođenih stranica.',
    'Overview' => 'Pregled',
    'PHP' => 'PHP',
    'Page' => 'Stranica',
    'Pages' => 'Stranice',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Odaberite jednu od sljedećih vrsta sadržaja. Vrsta sadržaja definira kako je vaš sadržaj ugrađen na vašu web lokaciju.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Imajte na umu da su stranice temeljene na php-u osjetljive na sigurnosne probleme, posebno kada se rukuje korisničkim unosom. Za više informacija pogledajte <a href="{url}">Najbolji primjeri iz Yii-jeve sigurnosti</a>.',
    'Public' => 'Javno',
    'Reset' => 'Reset',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Odaberite ovu postavku samo za vidljive čvorove teksta. Poništite ovu postavku u slučaju da se ovaj element koristi, na primjer, kao vrijednost HTML atributa.',
    'Settings' => 'Postavke',
    'Show additional file information (size)' => 'Prikaži dodatne podatke o datoteci (veličina)',
    'Snippet' => 'Isječak',
    'Snippets' => 'Isječci',
    'Sort Order' => 'Redoslijed',
    'Source' => 'Izvor (Source)',
    'Space' => 'Prostor',
    'Space Members only' => 'Samo članovi prostora',
    'Space Navigation' => 'Navigacija prostora',
    'Spaces' => 'Prostori',
    'Stream' => 'Stream',
    'Style' => 'Stil',
    'Submit' => 'Potvrdi',
    'Template' => 'Predložak',
    'Templates' => 'Predlošci',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Predlošci vam omogućuju definiranje kombiniranih fragmenata stranice s ugrađenim funkcijama uređivanja.',
    'This container does not allow any further items!' => 'Ovaj spremnik ne dopušta daljnje predmete!',
    'Title' => 'Naziv',
    'Top Navigation' => 'Top navigacija',
    'Topics' => 'Teme',
    'Type' => 'Vrsta',
    'Upload image' => 'Dodaj sliku',
    'User Account Menu (Settings)' => 'Izbornik korisničkog računa (Postavke)',
    'Visibility' => 'Vidljivost',
    'Will embed the result of a given url as an iframe element.' => 'Hoće li ugrađivati rezultat određenog URL-a kao element iframe-a.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Hoće li preusmjeriti zahtjeve na zadani (relativni ili apsolutni) url.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Sa stranicama temeljenim na PHP-u možete stvoriti prilagođene stranice pomoću pregleda datoteka u vašem datotečnom sustavu. Molimo provjerite konfiguraciju modula za više informacija.',
    'Without adding to navigation (Direct link)' => 'Bez dodavanja u navigaciju (izravna veza)',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Icon' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template Layout' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];
